@@ -12,27 +12,20 @@ def parse_args() -> tuple[str, dict[str, str], dict[str, str]]:
 
     create_parser = subparsers.add_parser("create")
     create_parser.add_argument("name", help="Package name")
-    for arg_name in Formatter.cmd_vars:
-        create_parser.add_argument(f"--{arg_name}")
+    create_parser.add_argument("--open", action="store_true", help="Open the project in vscode after creation")
+    create_parser.add_argument("--open-dir", action="store_true", help="Open the project folder after creation")
+    for arg_name, _var in Formatter.cmd_vars.items():
+        create_parser.add_argument(f"--{arg_name}", help=_var.desc)
 
     init_parser = subparsers.add_parser("init")
-    for arg_name in Formatter.conf_vars:
-        init_parser.add_argument(f"--{arg_name}")
+    for arg_name, _var in Formatter.conf_vars.items():
+        init_parser.add_argument(f"--{arg_name}", help="_var.desc")
 
     args = parser.parse_args()
-    args_dict = vars(args)
+    args_dict: dict[str, str] = vars(args)
 
-    cmd_args: dict[str, str] = {}
-    for arg_name in Formatter.conf_vars:
-        if arg_name in args_dict:
-            cmd_args[arg_name] = args_dict[arg_name]
-    args.cmd_args = cmd_args
-
-    conf_args: dict[str, str] = {}
-    for arg_name in Formatter.conf_vars:
-        if arg_name in args_dict:
-            conf_args[arg_name] = args_dict[arg_name]
-    args.conf_args = conf_args
+    args.cmd_args = {arg_name: args_dict[arg_name] for arg_name in Formatter.cmd_vars if arg_name in args_dict}
+    args.conf_args = {arg_name: args_dict[arg_name] for arg_name in Formatter.conf_vars if arg_name in args_dict}
 
     return args
 
@@ -46,11 +39,9 @@ def main():
         print(f"Created {confpath}")
     elif args.command == "create":
         try:
-            gen_project(args.name, args.cmd_args)
+            gen_project(args.name, args.cmd_args, args.open, args.open_dir)
         except GenException as e:
             print(e)
-    else:
-        print("Invalid Command")
 
 
 if __name__ == "__main__":
